package
module
Version:
v0.0.0-...-2e36113
Opens a new window with list of versions in this module.
Published: Jun 28, 2020
License: BSD-3-Clause
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 5
Opens a new window with list of known importers.
README
¶
go-logoutput

A writer that change output file every day
Exemple
Create a directory and the file 2006-01-02.log into.
package main
import (
"github.com/HuguesGuilleus/go-logoutput"
"log"
)
func main() {
logoutput.SetLog("log")
log.Println("Hello World")
}
Documentation
¶
Set the output of the standard log.
A logger output. You can use Zero value.
Write the content of data to the day file and into os.Stdout
Source Files
¶
Click to show internal directories.
Click to hide internal directories.